@@ -2,7 +2,7 @@ package Date::Japanese::Era::Table;
 
 use strict;
 use vars qw($VERSION);
-$VERSION = '0.01';
+$VERSION = '0.04';
 
 use vars qw(@ISA @EXPORT %ERA_TABLE %ERA_JA2ASCII %ERA_ASCII2JA);
 require Exporter;
@@ -11,10 +11,10 @@ require Exporter;
 
 %ERA_TABLE = (
     # era => [ $ascii, @begin_ymd, @end_ymd ]
-    '' => [ 'meiji', 1868, 9, 8, 1912, 7, 29 ],
-    '' => [ 'taishou', 1912, 7, 30, 1926, 12, 24 ],
-    '' => [ 'shouwa', 1926, 12, 25, 1989, 1, 7 ],
-    'ʿ' => [ 'heisei', 1989, 1, 8, 2999, 12, 31 ], # XXX
+    "\x{660E}\x{6CBB}" => [ 'meiji', 1868, 9, 8, 1912, 7, 29 ],
+    "\x{5927}\x{6B63}" => [ 'taishou', 1912, 7, 30, 1926, 12, 24 ],
+    "\x{662D}\x{548C}" => [ 'shouwa', 1926, 12, 25, 1989, 1, 7 ],
+    "\x{5E73}\x{6210}" => [ 'heisei', 1989, 1, 8, 2999, 12, 31 ], # XXX
 );
 
 %ERA_JA2ASCII = map { $_ => $ERA_TABLE{$_}->[0] } keys %ERA_TABLE;
